Changelog
=========

2.1 (2022-08-03)
----------------

- Support GITHUB_TOKEN environment variable to as a `--token` default
- Migrate package to pyproject + flit
- Enable CI via Github Actions


2.0 (2021-05-31)
----------------

Adds support for personal app tokens. This allow to access private repos.


1.1 (2019-04-22)
----------------

- Bugfix: Assignee not set.
- Inferred repo.


0.2 (aka 1.0 )(2016-03-19)
--------------------------

- Bump 0.2.
- State support throught metadata.
- Sync metadata with github.
- Better test.
- Clean metadata from body.
- Parse metadata.
- Better readme.
- Todo file as example.


0.1 (2016-03-15)
----------------
- Touches in readme.
- Rename package.
- Basic functional push command. can create or update issues.
- Basic command line. can pull from github.
- Basic github fetcher.
- Parser receive path.
- Basic parser based on docutils.
- Create README.md.


